@@ -14,7 +14,7 @@ DEFAULT_FONT_SIZE = 15
 DEFAULT_FONT_NAME = "Roboto-Medium"
 DEFAULT_TXT_COLOR = get_rgba_color((255, 255, 255, 1.0))
 # DEFAULT_TXT_THICKNESS = 1
-DEFAULT_SHADOW_COLOR = (0, 0, 0, 1.0)
+DEFAULT_SHADOW_COLOR = get_rgba_color((0, 0, 0, 1.0))
 DEFAULT_OPACITY = 100
 
 
