@@ -17,6 +17,7 @@ class VizPolygonDraw:
                  outline_thickness=utils.DEFAULT_ROI_OUTLINE_THICKNESS,
                  show_label=False,
                  label_size=utils.DEFAULT_LABEL_SIZE,
+                 label_color=utils.DEFAULT_LABEL_COLOR
                  ):
 
         self.show_roi = show_roi
@@ -39,6 +40,8 @@ class VizPolygonDraw:
         #     outline_thickness = DEFAULT_ROI_OUTLINE_THICKNESS
         # self.default_outline_thickness = int(outline_thickness)
 
+        self.label_color = get_rgba_color(label_color)
+
     def _draw_polygon_(
             self,
             draw: ImageDraw.Draw,
@@ -113,6 +116,7 @@ class VizPolygonDraw:
                     bbox=(x0, y0),
                     large_padding=True,
                     text=label,
+                    text_color=self.label_color,
                     show_shadow=True,
                     bbox_thickness=None,
                     bbox_color=None
